@@ -13,9 +13,9 @@ import os
 import signal
 import sys
 
-from . import find_binary, CommandNotFound, closerange
 from ..mappings import ProtectedDict
 from ..osutils import access
+from . import CommandNotFound, closerange, find_binary
 
 BASH_BINARY = find_binary('bash', fallback='/bin/bash')
 SANDBOX_BINARY = find_binary('sandbox', fallback='/usr/bin/sandbox')
@@ -395,11 +395,11 @@ def process_exit_code(retval):
 
 class ExecutionFailure(Exception):
     def __init__(self, msg):
-        Exception.__init__(self, msg)
+        super().__init__(msg)
         self.msg = msg
 
     def __str__(self):
-        return "Execution Failure: %s" % self.msg
+        return f'Execution Failure: {self.msg}'
 
 
 # cached capabilities
@@ -434,30 +434,3 @@ def is_userpriv_capable(force=False):
             pass
     res = is_userpriv_capable.cached_result = (os.getuid() == 0)
     return res
-
-
-_invoking_python = None
-def find_invoking_python():
-    # roughly... use sys.executable if possible, then major ver variations-
-    # look for python2.5, python2, then just python, for example
-    # NOTE: sys.executable in unreliable if the interpreter is embedded
-    global _invoking_python
-    if _invoking_python is not None and os.path.exists(_invoking_python):
-        return _invoking_python
-    if os.path.exists(sys.executable):
-        test_input = "oh hai"
-        returncode, output = spawn_get_output(
-            [sys.executable, '-c', 'print("%s")' % test_input], collect_fds=(1, 2))
-        if output and output[0].strip() == test_input:
-            _invoking_python = sys.executable
-            return _invoking_python
-
-    chunks = list(str(x) for x in sys.version_info[:2])
-    for potential in (chunks, chunks[:-1], ''):
-        try:
-            command_name = 'python%s' % '.'.join(potential)
-            _invoking_python = find_binary(command_name)
-            return _invoking_python
-        except CommandNotFound:
-            continue
-    raise CommandNotFound('python')
