@@ -1,11 +1,9 @@
-# Copyright: 2011 Brian Harring <ferringb@gmail.com>
-# License: BSD/GPL2
-
 """Version information."""
 
 import errno
-from importlib import import_module
 import os
+import subprocess
+from importlib import import_module
 
 _ver = None
 
@@ -32,57 +30,70 @@ def get_version(project, repo_file, api_version=None):
             try:
                 api_version = getattr(import_module(project), '__version__')
             except ImportError:
-                raise ValueError('no %s module in the syspath' % (project,))
+                raise ValueError(f'no {project} module in the syspath')
         try:
-            version_info = getattr(import_module(
-                '%s._verinfo' % (project,)), 'version_info')
+            version_info = getattr(
+                import_module(f'{project}._verinfo'), 'version_info')
         except ImportError:
             # we're probably in a git repo
-            cwd = os.path.dirname(os.path.abspath(repo_file))
-            version_info = get_git_version(cwd)
+            path = os.path.dirname(os.path.abspath(repo_file))
+            version_info = get_git_version(path)
 
         if version_info is None:
-            s = ", extended version info unavailable"
+            s = ''
         elif version_info['tag'] == api_version:
-            s = ', released %s' % (version_info['date'],)
+            s = f" -- released {version_info['date']}"
         else:
-            s = ('-g%s, %s' % (version_info['rev'][:7], version_info['date']))
+            rev = version_info['rev'][:7]
+            date = version_info['date']
+            commits = version_info.get('commits', None)
+            commits = f'-{commits}' if commits is not None else ''
+            s = f'{commits}-g{rev} -- {date}'
 
-        _ver = '%s %s%s' % (project, api_version, s)
+        _ver = f'{project} {api_version}{s}'
     return _ver
 
 
-def _run_git(cwd, cmd):
-    import subprocess
-
+def _run_git(path, cmd):
     env = dict(os.environ)
     env["LC_CTYPE"] = "C"
 
-    with open(os.devnull, 'wb') as null:
-        r = subprocess.Popen(
-            ['git'] + list(cmd), stdout=subprocess.PIPE, env=env,
-            stderr=null, cwd=cwd)
+    r = subprocess.Popen(
+        ['git'] + list(cmd), stdout=subprocess.PIPE, env=env,
+        stderr=subprocess.DEVNULL, cwd=path)
 
     stdout = r.communicate()[0]
     return stdout, r.returncode
 
 
-def get_git_version(cwd):
-    """:return: git sha1 rev"""
-
-    cwd = os.path.abspath(cwd)
+def get_git_version(path):
+    """Return git related revision data."""
+    path = os.path.abspath(path)
     try:
-        stdout, ret = _run_git(cwd, ["log", "--format=%H\n%ad", "HEAD^..HEAD"])
+        stdout, ret = _run_git(path, ["log", "--format=%H\n%aD", "HEAD^..HEAD"])
 
         if ret != 0:
             return None
 
-        data = stdout.decode("ascii").splitlines()
+        data = stdout.decode().splitlines()
+        tag = _get_git_tag(path, data[0])
+
+        # get number of commits since most recent tag
+        stdout, ret = _run_git(path, ['describe', '--tags', '--abbrev=0'])
+        prev_tag = None
+        commits = None
+        if ret == 0:
+            prev_tag = stdout.decode().strip()
+            stdout, ret = _run_git(
+                path, ['log', '--oneline', f'{prev_tag}..HEAD'])
+            if ret == 0:
+                commits = len(stdout.decode().splitlines())
 
         return {
-            "rev": data[0],
-            "date": data[1],
-            'tag': _get_git_tag(cwd, data[0]),
+            'rev': data[0],
+            'date': data[1],
+            'tag': tag,
+            'commits': commits,
         }
     except EnvironmentError as e:
         # ENOENT is thrown when the git binary can't be found.
@@ -91,9 +102,9 @@ def get_git_version(cwd):
         return None
 
 
-def _get_git_tag(cwd, rev):
-    stdout, _ = _run_git(cwd, ['name-rev', '--tag', rev])
-    tag = stdout.decode("ascii").split()
+def _get_git_tag(path, rev):
+    stdout, _ = _run_git(path, ['name-rev', '--tag', rev])
+    tag = stdout.decode().split()
     if len(tag) != 2:
         return None
     tag = tag[1]
